@@ -51,9 +51,36 @@
   )
 )
 
+.deprecations <- list(
+  credit_roles = \(caller, param) {
+    lifecycle::deprecate_warn(
+      "0.2.0",
+      what = glue("{caller}(credit_roles)"),
+      with = I(glue("`{param} = credit_roles()`"))
+    )
+  },
+  explicit_roles = \() {
+    lifecycle::deprecate_warn(
+      "0.2.0",
+      what = I("Defining explicit roles in the input data"),
+      with = "new(roles)",
+      details = paste0(
+        "See <",
+        "https://arnaudgallou.github.io/plume/articles/plume.html",
+        "#defining-roles-and-contributors",
+        ">."
+      )
+    )
+  }
+)
+
 # nocov start
 link <- function(id) {
   els <- .links[[id]]
-  md_link(els[2], els[1])
+  md_link(els[[2]], els[[1]])
+}
+
+print_deprecation <- function(id, ...) {
+  do.call(.deprecations[[id]], list(...))
 }
 # nocov end
